@@ -62,8 +62,9 @@ class Excel:
         if 'engine' in to_excel_kwargs:
             to_excel_kwargs.pop('engine')
 
-        writer = pd.ExcelWriter(filename, engine='openpyxl', mode='a', if_sheet_exists='overlay')
-        
+        if_sheet_exists = 'replace' if truncate_sheet is True else 'overlay'
+        writer = pd.ExcelWriter(filename, engine='openpyxl', mode='a', if_sheet_exists=if_sheet_exists)
+
         # get the last row in the existing Excel sheet if it was not specified explicitly
         if startrow is None:
             startrow = 0
@@ -89,10 +90,28 @@ class Excel:
         # writer.sheets = { ws.title:ws for ws in writer.book.worksheets }
 
         # make columns filterable
-        writer.book.active.auto_filter.ref = writer.book.active.dimensions
+        if sheet_name in writer.book.sheetnames:
+            # index of [sheet_name] sheet
+            idx = writer.book.sheetnames.index(sheet_name)
+            writer.book.worksheets[idx].auto_filter.ref = writer.book.worksheets[idx].dimensions
 
         # make columns autofit
-        # TODO
+        if sheet_name in writer.book.sheetnames:
+            # index of [sheet_name] sheet
+            idx = writer.book.sheetnames.index(sheet_name)
+            worksheet = writer.book.worksheets[idx]
+
+            for col in worksheet.columns:
+                max_length = 0
+                column = col[0].column_letter # Get the column name
+                for cell in col:
+                    try: # Necessary to avoid error on empty cells
+                        if len(str(cell.value)) > max_length:
+                            max_length = len(str(cell.value))
+                    except:
+                        pass
+                adjusted_width = (max_length + 2) * 1.2
+                worksheet.column_dimensions[column].width = adjusted_width
 
         # write out the new sheet
         df.to_excel(writer, sheet_name, startrow=startrow, header=header, **to_excel_kwargs)
